@@ -124,11 +124,7 @@ void pool_session_context_destroy(void)
 		pool_clear_sent_message_list();
 		free(session_context->message_list.sent_messages);
 		pool_memory_delete(session_context->memory_context, 0);
-
-		if (session_context->query_context)
-			pool_query_context_destroy(session_context->query_context);
 	}
-
 	/* XXX For now, just zap memory */
 	memset(&session_context_d, 0, sizeof(session_context_d));
 	session_context = NULL;
@@ -729,13 +725,6 @@ POOL_TRANSACTION_ISOLATION pool_get_transaction_isolation(void)
 	/* No cached data is available. Ask backend. */
 	status = do_query(MASTER(session_context->backend),
 					  "SELECT current_setting('transaction_isolation')", &res, MAJOR(session_context->backend));
-	if(status != POOL_CONTINUE)
-	{
-		pool_error("pool_get_transaction_isolation: do_query returns no rows");
-		if(res)
-			free_select_result(res);
-		return POOL_UNKNOWN;
-	}
 
 	if (res->numrows <= 0)
 	{
@@ -767,8 +756,7 @@ POOL_TRANSACTION_ISOLATION pool_get_transaction_isolation(void)
 		ret = POOL_UNKNOWN;
 	}   
 
-	if(res)
-		free_select_result(res);
+	free_select_result(res);
 
 	if (ret != POOL_UNKNOWN)
 		session_context->transaction_isolation = ret;
